@@ -21,6 +21,7 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
 
+#include <glib/gi18n-lib.h>
 #include <libgda/gda-config.h>
 #include <libgda/gda-data-model-array.h>
 #include <gtk/gtkimage.h>
@@ -29,7 +30,6 @@
 #include <gtk/gtktable.h>
 #include <gtk/gtkvbbox.h>
 #include <libgnomedb/gnome-db-grid.h>
-#include <libgnomedb/gnome-db-i18n.h>
 #include <libgnomedb/gnome-db-stock.h>
 #include <libgnomedb/gnome-db-util.h>
 #include <libgnomedb/gnome-db-data-widget.h>
@@ -70,8 +70,6 @@ show_providers (ProviderConfigPrivate *priv)
 		g_list_free (value_list);
 	}
 
-	gda_config_free_provider_list (prv_list);
-
 	/* display the new data model */
 	gnome_db_data_widget_set_gda_model (GNOME_DB_DATA_WIDGET (priv->provider_list), NULL, model);
 	g_object_unref (G_OBJECT (model));
@@ -135,7 +133,8 @@ provider_config_new (void)
 		_("Providers are external plugins that provide access "
 		  "to a specific data source. The default provider is "
 		  "always installed, which allows access to databases "
-		  "stored in XML files. Other providers usually "
+		  "stored in files (using the SQLite embedded database). "
+		  " Other providers usually "
 		  "distributed along with libgda/gnome-db include "
 		  "PostgreSQL, MySQL, Oracle, Sybase, Interbase, etc."));
 	gtk_label_set_line_wrap (GTK_LABEL (label), TRUE);
