@@ -192,8 +192,17 @@ open_connection (BrowserConfig *config, gboolean force_update)
 		
 		conn_opened = gnome_db_server_open_connect (server, &error);
 		if (!conn_opened) {
-			gnome_db_show_error (error->message);
-			g_error_free (error);
+			GtkWidget *errdialog;
+			
+			errdialog = gnome_db_new_alert (GTK_WINDOW (dialog), 
+							GTK_MESSAGE_ERROR, _("Error opening connection:"), 
+							error && error->message ? error->message : _("no detail"));
+			gtk_widget_show (errdialog);
+			gtk_dialog_run (GTK_DIALOG (errdialog));
+			gtk_widget_destroy (errdialog);
+
+			if (error)
+				g_error_free (error);
 			error = NULL;
 		}
 		else 
@@ -960,9 +969,14 @@ table_view_contents (GtkWidget *button, BrowserConfig *config)
 		gtk_widget_set_size_request (grid, 400, 250);
 		
 		gtk_widget_show_all (dlg);
-		/* gnome_db_data_widget_run (GNOME_DB_DATA_WIDGET (grid),  */
-/* 					  GNOME_DB_ACTION_ASK_CONFIRM_DELETE | GNOME_DB_ACTION_ASK_CONFIRM_UPDATE |  */
-/* 					  GNOME_DB_ACTION_ASK_CONFIRM_INSERT); */
+		gnome_db_grid_set_sample_size (GNOME_DB_GRID (grid), 300);
+		gnome_db_data_widget_set_mode (GNOME_DB_DATA_WIDGET (grid),
+                                               GNOME_DB_ACTION_ASK_CONFIRM_UPDATE |
+                                               GNOME_DB_ACTION_ASK_CONFIRM_DELETE |
+                                               GNOME_DB_ACTION_ASK_CONFIRM_INSERT |
+                                               GNOME_DB_ACTION_REPORT_ERROR |
+                                               GNOME_DB_ACTION_NAVIGATION_ARROWS);
+
 		g_object_unref (G_OBJECT (query));
 		g_object_set_data (G_OBJECT (table), "contents", dlg);
 		g_signal_connect (G_OBJECT (dlg), "response",
