@@ -66,7 +66,7 @@ static gint gnome_db_basic_form_signals[LAST_SIGNAL] = { 0 };
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass *parent_class = NULL;
 
-guint
+GType
 gnome_db_basic_form_get_type (void)
 {
 	static GType type = 0;
@@ -183,7 +183,7 @@ gnome_db_basic_form_new_in_layout (GnomeDbDict *dict, GnomeDbDataSet *data_set,
 		}
 	}
 
-	obj = g_object_new (GNOME_DB_BASIC_FORM_TYPE, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_BASIC_FORM, NULL);
 	form = GNOME_DB_BASIC_FORM (obj);
 
 	form->priv->dict = ASSERT_DICT (dict);
@@ -358,10 +358,12 @@ gnome_db_basic_form_initialize (GnomeDbBasicForm *form, GnomeDbDict *dict, GtkWi
 				dh = gnome_db_server_get_handler_by_name (gnome_db_dict_get_server (dict), plugin);
 
 				/* test if plugin can handle the parameter's data type */
-				if (!gnome_db_data_handler_accepts_gda_type (dh, gnome_db_server_data_type_get_gda_type (type)))
+				if (dh && 
+				    !gnome_db_data_handler_accepts_gda_type (dh, gnome_db_server_data_type_get_gda_type (type)))
 					dh = NULL;
 			}
-			else
+			
+			if (!dh)
 				dh = gnome_db_server_data_type_get_handler (type);
 			val = gnome_db_parameter_get_value (param);
 			default_val = gnome_db_parameter_get_default_value (param);
@@ -743,6 +745,24 @@ parameter_changed_cb (GnomeDbParameter *param, GnomeDbDataEntry *entry)
 	}
 }
 
+/**
+ * gnome_db_basic_form_get_data_set
+ * @form: a #GnomeDbBasicForm widget
+ *
+ * Get a pointer to the #GnomeDbDataSet used internally by @form to store
+ * values
+ *
+ * Returns:
+ */
+GnomeDbDataSet *
+gnome_db_basic_form_get_data_set (GnomeDbBasicForm *form)
+{
+	g_return_val_if_fail (form && IS_GNOME_DB_BASIC_FORM (form), NULL);
+	g_return_val_if_fail (form->priv, NULL);
+
+	return form->priv->data_set;
+}
+
 /**
  * gnome_db_basic_form_set_current_as_orig
  * @form: a #GnomeDbBasicForm widget
@@ -866,7 +886,7 @@ gnome_db_basic_form_show_entries_actions (GnomeDbBasicForm *form, gboolean show_
 		entries = g_slist_next (entries);
 	}
 
-	mark_not_null_entry_labels (form, show_actions);
+	/* mark_not_null_entry_labels (form, show_actions); */
 }
 
 /**
