@@ -128,7 +128,7 @@ GQuark gnome_db_condition_error_quark (void)
 }
 
 
-guint
+GType
 gnome_db_condition_get_type (void)
 {
 	static GType type = 0;
@@ -164,10 +164,10 @@ gnome_db_condition_get_type (void)
                         NULL
                 };
 
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbCondition", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_XML_STORAGE_TYPE, &xml_storage_info);
-                g_type_add_interface_static (type, GNOME_DB_RENDERER_TYPE, &renderer_info);
-                g_type_add_interface_static (type, GNOME_DB_REFERER_TYPE, &referer_info);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbCondition", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_XML_STORAGE, &xml_storage_info);
+                g_type_add_interface_static (type, GNOME_DB_TYPE_RENDERER, &renderer_info);
+                g_type_add_interface_static (type, GNOME_DB_TYPE_REFERER, &referer_info);
 	}
 	return type;
 }
@@ -262,7 +262,7 @@ gnome_db_condition_new (GnomeDbQuery *query, GnomeDbConditionType type)
 	g_return_val_if_fail (query && IS_GNOME_DB_QUERY (query), NULL);
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (query));
 
-	obj = g_object_new (GNOME_DB_CONDITION_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_CONDITION, "dict", dict, NULL);
 	g_object_get (G_OBJECT (query), "cond_serial", &id, NULL);
 	gnome_db_base_set_id (GNOME_DB_BASE (obj), id);
 
@@ -318,7 +318,7 @@ gnome_db_condition_new_copy (GnomeDbCondition *orig, GHashTable *replacements)
 	g_return_val_if_fail (query, NULL);
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (query));
 
-	obj = g_object_new (GNOME_DB_CONDITION_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_CONDITION, "dict", dict, NULL);
 	g_object_get (G_OBJECT (query), "cond_serial", &id, NULL);
 	gnome_db_base_set_id (GNOME_DB_BASE (obj), id);
 
@@ -866,7 +866,7 @@ gnome_db_condition_leaf_set_operator (GnomeDbCondition *condition, GnomeDbCondit
 	g_return_if_fail (query1);
 	g_return_if_fail (query1 == query2);
 
-	gnome_db_ref_base_set_ref_object_type (condition->priv->ops[op], GNOME_DB_BASE (field), GNOME_DB_QFIELD_TYPE);
+	gnome_db_ref_base_set_ref_object_type (condition->priv->ops[op], GNOME_DB_BASE (field), GNOME_DB_TYPE_QFIELD);
 }
 
 /**
@@ -1468,7 +1468,7 @@ gnome_db_condition_load_from_xml (GnomeDbXmlStorage *iface, xmlNodePtr node, GEr
 
 	prop = xmlGetProp (node, "l_op");
 	if (prop) {
-		gnome_db_ref_base_set_ref_name (cond->priv->ops[GNOME_DB_CONDITION_OP_LEFT], GNOME_DB_QFIELD_TYPE,
+		gnome_db_ref_base_set_ref_name (cond->priv->ops[GNOME_DB_CONDITION_OP_LEFT], GNOME_DB_TYPE_QFIELD,
 					  REFERENCE_BY_XML_ID, prop);
 		g_free (prop);
 	}
@@ -1476,14 +1476,14 @@ gnome_db_condition_load_from_xml (GnomeDbXmlStorage *iface, xmlNodePtr node, GEr
 
 	prop = xmlGetProp (node, "r_op");
 	if (prop) {
-		gnome_db_ref_base_set_ref_name (cond->priv->ops[GNOME_DB_CONDITION_OP_RIGHT], GNOME_DB_QFIELD_TYPE,
+		gnome_db_ref_base_set_ref_name (cond->priv->ops[GNOME_DB_CONDITION_OP_RIGHT], GNOME_DB_TYPE_QFIELD,
 					  REFERENCE_BY_XML_ID, prop);
 		g_free (prop);
 	}
 
 	prop = xmlGetProp (node, "r_op2");
 	if (prop) {
-		gnome_db_ref_base_set_ref_name (cond->priv->ops[GNOME_DB_CONDITION_OP_RIGHT2], GNOME_DB_QFIELD_TYPE,
+		gnome_db_ref_base_set_ref_name (cond->priv->ops[GNOME_DB_CONDITION_OP_RIGHT2], GNOME_DB_TYPE_QFIELD,
 					  REFERENCE_BY_XML_ID, prop);
 		g_free (prop);
 	}
