@@ -150,9 +150,9 @@ gnome_db_constraint_get_type (void)
 			NULL
 		};
 		
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbConstraint", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_XML_STORAGE_TYPE, &xml_storage_info);
-		g_type_add_interface_static (type, GNOME_DB_REFERER_TYPE, &referer_info);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbConstraint", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_XML_STORAGE, &xml_storage_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_REFERER, &referer_info);
 	}
 	return type;
 }
@@ -243,7 +243,7 @@ gnome_db_constraint_new (GnomeDbTable *table, GnomeDbConstraintType type)
 	g_return_val_if_fail (table && IS_GNOME_DB_TABLE (table), NULL);
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (table));
 	
-	obj = g_object_new (GNOME_DB_CONSTRAINT_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_CONSTRAINT, "dict", dict, NULL);
 
 	gnome_db_constraint = GNOME_DB_CONSTRAINT (obj);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_constraint), 0);
@@ -278,7 +278,7 @@ gnome_db_constraint_new_with_db (GnomeDbDatabase *db)
 	g_return_val_if_fail (db && IS_GNOME_DB_DATABASE (db), NULL);
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (db));
 	
-	obj = g_object_new (GNOME_DB_CONSTRAINT_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_CONSTRAINT, "dict", dict, NULL);
 
 	gnome_db_constraint = GNOME_DB_CONSTRAINT (obj);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_constraint), 0);
@@ -744,7 +744,7 @@ gnome_db_constraint_fkey_set_fields (GnomeDbConstraint *cstr, const GSList *pair
 				return;	
 			}
 			if (gnome_db_ref_base_get_ref_type (pair->ref_pkey_repl) !=
-			    GNOME_DB_TABLE_FIELD_TYPE) {
+			    GNOME_DB_TYPE_TABLE_FIELD) {
 				g_warning ("Pair item %p has ref_pkey_repl which does not reference a field", list->data);
 				return;	
 			}
@@ -1065,15 +1065,18 @@ gnome_db_constraint_dump (GnomeDbConstraint *cstr, guint offset)
 static gchar *
 gnome_db_constraint_get_xml_id (GnomeDbXmlStorage *iface)
 {
-	gchar *t_xml_id, *xml_id;
+	gchar *t_xml_id, *tmp, *xml_id;
 
 	g_return_val_if_fail (iface && IS_GNOME_DB_CONSTRAINT (iface), NULL);
 	g_return_val_if_fail (GNOME_DB_CONSTRAINT (iface)->priv, NULL);
 	g_return_val_if_fail (GNOME_DB_CONSTRAINT (iface)->priv->table, NULL);
 
 	t_xml_id = gnome_db_xml_storage_get_xml_id (GNOME_DB_XML_STORAGE (GNOME_DB_CONSTRAINT (iface)->priv->table));
-	xml_id = g_strdup_printf ("%s:FI%s", t_xml_id, gnome_db_base_get_name (GNOME_DB_BASE (iface)));
+	tmp = utility_build_encoded_id ("FI", gnome_db_base_get_name (GNOME_DB_BASE (iface)));
+	xml_id = g_strdup_printf ("%s:%s", t_xml_id, tmp);
 	g_free (t_xml_id);
+	g_free (tmp);
+	g_assert_not_reached ();
 	
 	return xml_id;
 }
