@@ -165,9 +165,9 @@ gnome_db_custom_layout_get_type (void)
 			NULL
 		};
 		
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbCustomLayout", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_XML_STORAGE_TYPE, &xml_storage_info);
-		g_type_add_interface_static (type, GNOME_DB_REFERER_TYPE, &referer_info);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbCustomLayout", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_XML_STORAGE, &xml_storage_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_REFERER, &referer_info);
 	}
 	return type;
 }
@@ -229,7 +229,7 @@ gnome_db_custom_layout_new (GnomeDbDict *dict)
 
 	g_return_val_if_fail (!dict || IS_GNOME_DB_DICT (dict), NULL);
 
-	obj = g_object_new (GNOME_DB_CUSTOM_LAYOUT_TYPE, "dict", ASSERT_DICT (dict), NULL);
+	obj = g_object_new (GNOME_DB_TYPE_CUSTOM_LAYOUT, "dict", ASSERT_DICT (dict), NULL);
         gnome_db_custom_layout = GNOME_DB_CUSTOM_LAYOUT (obj);
 
 	g_object_get (G_OBJECT (ASSERT_DICT (dict)), "layout_serial", &id, NULL);
@@ -1274,22 +1274,22 @@ gnome_db_custom_layout_load_from_xml (GnomeDbXmlStorage *iface, xmlNodePtr node,
 			lc = layout_connect_new (cl, dict);
 			prop = xmlGetProp (children, "src_layout");
 			g_assert (prop); /* normally done through DTD */
-			gnome_db_ref_base_set_ref_name (lc->src_layout, GNOME_DB_CUSTOM_LAYOUT_TYPE, REFERENCE_BY_XML_ID, prop);
+			gnome_db_ref_base_set_ref_name (lc->src_layout, GNOME_DB_TYPE_CUSTOM_LAYOUT, REFERENCE_BY_XML_ID, prop);
 			g_free (prop);
 
 			prop = xmlGetProp (children, "src_field");
 			g_assert (prop); /* normally done through DTD */
-			gnome_db_ref_base_set_ref_name (lc->src_field, GNOME_DB_FIELD_TYPE, REFERENCE_BY_XML_ID, prop);
+			gnome_db_ref_base_set_ref_name (lc->src_field, GNOME_DB_TYPE_FIELD, REFERENCE_BY_XML_ID, prop);
 			g_free (prop);
 
 			prop = xmlGetProp (children, "dest_layout");
 			g_assert (prop); /* normally done through DTD */
-			gnome_db_ref_base_set_ref_name (lc->dest_layout, GNOME_DB_CUSTOM_LAYOUT_TYPE, REFERENCE_BY_XML_ID, prop);
+			gnome_db_ref_base_set_ref_name (lc->dest_layout, GNOME_DB_TYPE_CUSTOM_LAYOUT, REFERENCE_BY_XML_ID, prop);
 			g_free (prop);
 
 			prop = xmlGetProp (children, "dest_field");
 			g_assert (prop); /* normally done through DTD */
-			gnome_db_ref_base_set_ref_name (lc->dest_field, GNOME_DB_FIELD_TYPE, REFERENCE_BY_XML_ID, prop);
+			gnome_db_ref_base_set_ref_name (lc->dest_field, GNOME_DB_TYPE_FIELD, REFERENCE_BY_XML_ID, prop);
 			g_free (prop);
 
 			cl->priv->contents.layout.connects = g_slist_append (cl->priv->contents.layout.connects, lc);
