@@ -118,7 +118,7 @@ gnome_db_data_set_get_type (void)
 			(GInstanceInitFunc) gnome_db_data_set_init
 		};
 		
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbDataSet", &info, 0);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbDataSet", &info, 0);
 	}
 	return type;
 }
@@ -196,7 +196,7 @@ gnome_db_data_set_new (GnomeDbDict *dict, GSList *params)
 
 	g_return_val_if_fail (!dict || IS_GNOME_DB_DICT (dict), NULL);
 
-	obj = g_object_new (GNOME_DB_DATA_SET_TYPE, "dict", ASSERT_DICT (dict), NULL);
+	obj = g_object_new (GNOME_DB_TYPE_DATA_SET, "dict", ASSERT_DICT (dict), NULL);
         gnome_db_data_set = GNOME_DB_DATA_SET (obj);
         gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_data_set), 0);
 
@@ -247,7 +247,7 @@ gnome_db_data_set_new_copy (GnomeDbDataSet *orig, GHashTable *replacements)
 	g_return_val_if_fail (orig && IS_GNOME_DB_DATA_SET (orig), NULL);
 
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (orig));
-	obj = g_object_new (GNOME_DB_DATA_SET_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_DATA_SET, "dict", dict, NULL);
 	gnome_db_data_set = GNOME_DB_DATA_SET (obj);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_data_set), 0);
 
