@@ -1,8 +1,10 @@
 /* GNOME DB library
- * Copyright (C) 1999-2002 The GNOME Foundation.
+ *
+ * Copyright (C) 1999 - 2005 The GNOME Foundation.
  *
  * AUTHORS:
  *      Rodrigo Moya <rodrigo@gnome-db.org>
+ *      Vivien Malerba <malerba@gnome-db.org>
  *
  * This Library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Library General Public License as
@@ -22,7 +24,8 @@
 
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
-#include <libgnomedb/gnome-db-gray-bar.h>
+#include "gnome-db-gray-bar.h"
+#include "gnome-db-decl.h"
 
 #define PARENT_TYPE GTK_TYPE_BIN
 
@@ -349,6 +352,11 @@ gnome_db_gray_bar_get_type (void)
 
 /**
  * gnome_db_gray_bar_new
+ * @label:
+ *
+ *
+ *
+ * Returns:
  */
 GtkWidget *
 gnome_db_gray_bar_new (const gchar *label)
@@ -386,6 +394,7 @@ gnome_db_gray_bar_get_text (GnomeDbGrayBar *bar)
 /**
  * gnome_db_gray_bar_set_text
  * @bar: A #GnomeDbGrayBar widget
+ * @text:
  *
  * Set the text displayed in the given gray bar widget. This can include 
  * embedded underlines indicating mnemonics or Pango markup.
