@@ -146,7 +146,7 @@ enum
 {
         SELECTION_CHANGED,
 	DOUBLE_CLICKED,
-	CREATE_POPUP_MENU,
+	POPULATE_POPUP,
         LAST_SIGNAL
 };
 
@@ -188,7 +188,7 @@ gnome_db_grid_get_type (void)
                 };
 		
 		type = g_type_register_static (GTK_TYPE_VBOX, "GnomeDbGrid", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_DATA_WIDGET_TYPE, &work_widget_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_DATA_WIDGET, &work_widget_info);
 	}
 
 	return type;
@@ -235,11 +235,11 @@ gnome_db_grid_class_init (GnomeDbGridClass * class)
                               NULL, NULL,
                               marshal_VOID__INT, G_TYPE_NONE,
                               1, G_TYPE_INT);
-	gnome_db_grid_signals[CREATE_POPUP_MENU] = 
-		g_signal_new ("create_popup_menu",
+	gnome_db_grid_signals[POPULATE_POPUP] = 
+		g_signal_new ("populate_popup",
                               G_TYPE_FROM_CLASS (object_class),
                               G_SIGNAL_RUN_FIRST,
-                              G_STRUCT_OFFSET (GnomeDbGridClass, create_popup_menu),
+                              G_STRUCT_OFFSET (GnomeDbGridClass, populate_popup),
                               NULL, NULL,
                               marshal_VOID__POINTER, G_TYPE_NONE,
                               1, G_TYPE_POINTER);
@@ -300,7 +300,7 @@ gnome_db_grid_new (void)
 {
 	GObject *obj;
 	
-	obj = g_object_new (GNOME_DB_GRID_TYPE, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_GRID, NULL);
 
 	return GTK_WIDGET (obj);
 }
@@ -359,7 +359,7 @@ gnome_db_grid_new_with_select_query (GnomeDbQuery *query, GnomeDbTarget *modifie
 		g_return_val_if_fail (gnome_db_entity_is_writable (gnome_db_target_get_represented_entity (modified)), NULL);
 	}
 	
-	obj = g_object_new (GNOME_DB_GRID_TYPE, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_GRID, NULL);
 	grid = GNOME_DB_GRID (obj);
 
 	rs = GNOME_DB_RESULT_SET (gnome_db_result_set_new (query, modified));
@@ -1617,7 +1617,7 @@ tree_view_popup_button_pressed_cb (GtkWidget *widget, GdkEventButton *event, Gno
 	}
 
 	/* allow listeners to add their custom menu items */
-        g_signal_emit (G_OBJECT (grid), gnome_db_grid_signals [CREATE_POPUP_MENU], 0, GTK_MENU (menu));
+        g_signal_emit (G_OBJECT (grid), gnome_db_grid_signals [POPULATE_POPUP], 0, GTK_MENU (menu));
         gtk_menu_popup (GTK_MENU (menu), NULL, NULL, NULL, NULL, event->button, event->time);
         gtk_widget_show_all (menu);
 	
@@ -1810,7 +1810,7 @@ save_as_response_cb (GtkDialog *dialog, guint response_id, GnomeDbGrid *grid)
 				}
 
 				if (! gda_file_save (path, body, strlen (body))) {
-					gnome_db_show_error (_("Could not save file %s"), path);
+					gnome_db_show_error (NULL, _("Could not save file %s"), path);
 					g_free (body);
 					g_free (path);
 					return;
@@ -1818,13 +1818,13 @@ save_as_response_cb (GtkDialog *dialog, guint response_id, GnomeDbGrid *grid)
 				g_free (path);
 			} 
 			else {
-				gnome_db_show_error (_("You must specify a file name"));
+				gnome_db_show_error (NULL, _("You must specify a file name"));
 				g_free (body);
 				return;
 			}
 			g_free (body);
 		} else
-			gnome_db_show_error (_("Got empty file while converting the data"));
+			gnome_db_show_error (NULL,_("Got empty file while converting the data"));
 	}
 
 	gtk_widget_destroy (GTK_WIDGET (dialog));
