@@ -28,7 +28,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_GRID_TYPE          (gnome_db_grid_get_type())
+#define GNOME_DB_TYPE_GRID          (gnome_db_grid_get_type())
 #define GNOME_DB_GRID(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_grid_get_type(), GnomeDbGrid)
 #define GNOME_DB_GRID_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_grid_get_type (), GnomeDbGridClass)
 #define IS_GNOME_DB_GRID(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_grid_get_type ())
@@ -54,7 +54,7 @@ struct _GnomeDbGridClass
 
 	void             (* selection_changed) (GnomeDbGrid *grid, gboolean row_selected);
 	void             (* double_clicked)    (GnomeDbGrid *grid, gint row);
-        void             (* create_popup_menu) (GnomeDbGrid *grid, GtkWidget *menu);
+        void             (* populate_popup)    (GnomeDbGrid *grid, GtkMenu *menu);
 };
 
 /* 
