@@ -28,7 +28,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_JOIN_TYPE          (gnome_db_join_get_type())
+#define GNOME_DB_TYPE_JOIN          (gnome_db_join_get_type())
 #define GNOME_DB_JOIN(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_join_get_type(), GnomeDbJoin)
 #define GNOME_DB_JOIN_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_join_get_type (), GnomeDbJoinClass)
 #define IS_GNOME_DB_JOIN(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_join_get_type ())
