@@ -29,7 +29,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_MODEL_WRAPPER_TYPE          (gnome_db_model_wrapper_get_type())
+#define GNOME_DB_TYPE_MODEL_WRAPPER          (gnome_db_model_wrapper_get_type())
 #define GNOME_DB_MODEL_WRAPPER(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_model_wrapper_get_type(), GnomeDbModelWrapper)
 #define GNOME_DB_MODEL_WRAPPER_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_model_wrapper_get_type (), GnomeDbModelWrapperClass)
 #define IS_GNOME_DB_MODEL_WRAPPER(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_model_wrapper_get_type ())
