@@ -150,8 +150,8 @@ gnome_db_parameter_get_type (void)
 			NULL
 		};
 		
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbParameter", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_REFERER_TYPE, &referer_info);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbParameter", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_REFERER, &referer_info);
 	}
 	return type;
 }
@@ -238,7 +238,7 @@ gnome_db_parameter_new (GnomeDbDict *dict, GnomeDbServerDataType *type)
         g_return_val_if_fail (!dict || IS_GNOME_DB_DICT (dict), NULL);
 	g_return_val_if_fail (type && IS_GNOME_DB_SERVER_DATA_TYPE (type), NULL);
 
-        obj = g_object_new (GNOME_DB_PARAMETER_TYPE, "dict", ASSERT_DICT (dict), NULL);
+        obj = g_object_new (GNOME_DB_TYPE_PARAMETER, "dict", ASSERT_DICT (dict), NULL);
 	param = GNOME_DB_PARAMETER (obj);
 
 	gnome_db_parameter_set_data_type (param, type);
@@ -264,7 +264,7 @@ gnome_db_parameter_new_copy (GnomeDbParameter *orig)
 	g_return_val_if_fail (orig && IS_GNOME_DB_PARAMETER (orig), NULL);
 	g_return_val_if_fail (orig->priv, NULL);
 
-	obj = g_object_new (GNOME_DB_PARAMETER_TYPE, "dict", gnome_db_base_get_dict (GNOME_DB_BASE (orig)), NULL);
+	obj = g_object_new (GNOME_DB_TYPE_PARAMETER, "dict", gnome_db_base_get_dict (GNOME_DB_BASE (orig)), NULL);
 	param = GNOME_DB_PARAMETER (obj);
 
 	gnome_db_base_set_name (GNOME_DB_BASE (param), gnome_db_base_get_name (GNOME_DB_BASE (orig)));
@@ -332,7 +332,7 @@ gnome_db_parameter_new_with_dest_field (GnomeDbField *field, GnomeDbServerDataTy
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (field));
 	g_return_val_if_fail (dict, NULL);
 
-        obj = g_object_new (GNOME_DB_PARAMETER_TYPE, "dict", dict, NULL);
+        obj = g_object_new (GNOME_DB_TYPE_PARAMETER, "dict", dict, NULL);
 	param = GNOME_DB_PARAMETER (obj);
 
 	gnome_db_parameter_add_for_field (param, field);
