@@ -29,7 +29,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_PARAMETER_TYPE          (gnome_db_parameter_get_type())
+#define GNOME_DB_TYPE_PARAMETER          (gnome_db_parameter_get_type())
 #define GNOME_DB_PARAMETER(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_parameter_get_type(), GnomeDbParameter)
 #define GNOME_DB_PARAMETER_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_parameter_get_type (), GnomeDbParameterClass)
 #define IS_GNOME_DB_PARAMETER(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_parameter_get_type ())
