@@ -166,11 +166,11 @@ gnome_db_qf_all_get_type (void)
 		};
 		
 		
-		type = g_type_register_static (GNOME_DB_QFIELD_TYPE, "GnomeDbQfAll", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_XML_STORAGE_TYPE, &xml_storage_info);
-		g_type_add_interface_static (type, GNOME_DB_FIELD_TYPE, &field_info);
-		g_type_add_interface_static (type, GNOME_DB_RENDERER_TYPE, &renderer_info);
-		g_type_add_interface_static (type, GNOME_DB_REFERER_TYPE, &referer_info);
+		type = g_type_register_static (GNOME_DB_TYPE_QFIELD, "GnomeDbQfAll", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_XML_STORAGE, &xml_storage_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_FIELD, &field_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_RENDERER, &renderer_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_REFERER, &referer_info);
 	}
 	return type;
 }
@@ -279,7 +279,7 @@ gnome_db_qf_all_new_with_target (GnomeDbQuery *query, GnomeDbTarget *target)
 	g_return_val_if_fail (gnome_db_target_get_query (target) == query, NULL);
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (query));
 
-	obj = g_object_new (GNOME_DB_QF_ALL_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_QF_ALL, "dict", dict, NULL);
 	gnome_db_qf_all = GNOME_DB_QF_ALL (obj);
 	g_object_get (G_OBJECT (query), "field_serial", &id, NULL);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_qf_all), id);
@@ -325,7 +325,7 @@ gnome_db_qf_all_new_with_xml_id (GnomeDbQuery *query, const gchar *target_xml_id
 	g_free (str);
 
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (query));
-	obj = g_object_new (GNOME_DB_QF_ALL_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_QF_ALL, "dict", dict, NULL);
 	gnome_db_qf_all = GNOME_DB_QF_ALL (obj);
 	g_object_get (G_OBJECT (query), "field_serial", &id, NULL);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_qf_all), id);
@@ -337,7 +337,7 @@ gnome_db_qf_all_new_with_xml_id (GnomeDbQuery *query, const gchar *target_xml_id
 			  G_CALLBACK (target_removed_cb), gnome_db_qf_all);
 
 	gnome_db_qf_all->priv->target_ref = GNOME_DB_REF_BASE (gnome_db_ref_base_new (dict));
-	gnome_db_ref_base_set_ref_name (gnome_db_qf_all->priv->target_ref, GNOME_DB_TARGET_TYPE, REFERENCE_BY_XML_ID, target_xml_id);
+	gnome_db_ref_base_set_ref_name (gnome_db_qf_all->priv->target_ref, GNOME_DB_TYPE_TARGET, REFERENCE_BY_XML_ID, target_xml_id);
 	
 	return obj;
 }
@@ -675,7 +675,7 @@ gnome_db_qf_all_load_from_xml (GnomeDbXmlStorage *iface, xmlNodePtr node, GError
 	prop = xmlGetProp (node, "target");
 	if (prop) {
 		target = TRUE;
-		gnome_db_ref_base_set_ref_name (field->priv->target_ref, GNOME_DB_TARGET_TYPE, REFERENCE_BY_XML_ID, prop);
+		gnome_db_ref_base_set_ref_name (field->priv->target_ref, GNOME_DB_TYPE_TARGET, REFERENCE_BY_XML_ID, prop);
 		g_free (prop);
 	}
 
