@@ -106,7 +106,7 @@ gnome_db_qfield_get_type (void)
 			(GInstanceInitFunc) gnome_db_qfield_init
 		};
 		
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbQfield", &info, 0);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbQfield", &info, 0);
 	}
 	return type;
 }
