@@ -29,7 +29,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_QUERY_TYPE          (gnome_db_query_get_type())
+#define GNOME_DB_TYPE_QUERY          (gnome_db_query_get_type())
 #define GNOME_DB_QUERY(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_query_get_type(), GnomeDbQuery)
 #define GNOME_DB_QUERY_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_query_get_type (), GnomeDbQueryClass)
 #define IS_GNOME_DB_QUERY(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_query_get_type ())
