@@ -129,7 +129,7 @@ gnome_db_ref_base_get_type (void)
 			(GInstanceInitFunc) gnome_db_ref_base_init
 		};		
 		
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbRefBase", &info, 0);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbRefBase", &info, 0);
 	}
 	return type;
 }
@@ -209,7 +209,7 @@ gnome_db_ref_base_new (GnomeDbDict *dict)
 
 	g_return_val_if_fail (!dict || IS_GNOME_DB_DICT (dict), NULL);
 
-	obj = g_object_new (GNOME_DB_REF_BASE_TYPE, "dict", ASSERT_DICT (dict), NULL);
+	obj = g_object_new (GNOME_DB_TYPE_REF_BASE, "dict", ASSERT_DICT (dict), NULL);
 	gnome_db_ref_base = GNOME_DB_REF_BASE (obj);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_ref_base), 0);
 
@@ -257,7 +257,7 @@ gnome_db_ref_base_new_copy (GnomeDbRefBase *orig)
 
 	g_return_val_if_fail (orig && IS_GNOME_DB_REF_BASE (orig), NULL);
 
-	obj = g_object_new (GNOME_DB_REF_BASE_TYPE, "dict", gnome_db_base_get_dict (GNOME_DB_BASE (orig)), NULL);
+	obj = g_object_new (GNOME_DB_TYPE_REF_BASE, "dict", gnome_db_base_get_dict (GNOME_DB_BASE (orig)), NULL);
 	gnome_db_ref_base = GNOME_DB_REF_BASE (obj);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_ref_base), 0);
 
@@ -400,23 +400,23 @@ handled_object_type (GType type)
 	GType retval = 0;
 
 	/* types accepted AS IS */
-	if ((type == GNOME_DB_TABLE_TYPE) ||
-	    (type == GNOME_DB_TABLE_FIELD_TYPE) ||
-	    (type == GNOME_DB_QUERY_TYPE) ||
-	    (type == GNOME_DB_TARGET_TYPE) ||
-	    (type == GNOME_DB_FIELD_TYPE) ||
-	    (type == GNOME_DB_SERVER_FUNCTION_TYPE) ||
-	    (type == GNOME_DB_SERVER_AGGREGATE_TYPE) ||
-	    (type == GNOME_DB_QFIELD_TYPE) ||
-	    (type == GNOME_DB_CUSTOM_LAYOUT_TYPE))
+	if ((type == GNOME_DB_TYPE_TABLE) ||
+	    (type == GNOME_DB_TYPE_TABLE_FIELD) ||
+	    (type == GNOME_DB_TYPE_QUERY) ||
+	    (type == GNOME_DB_TYPE_TARGET) ||
+	    (type == GNOME_DB_TYPE_FIELD) ||
+	    (type == GNOME_DB_TYPE_SERVER_FUNCTION) ||
+	    (type == GNOME_DB_TYPE_SERVER_AGGREGATE) ||
+	    (type == GNOME_DB_TYPE_QFIELD) ||
+	    (type == GNOME_DB_TYPE_CUSTOM_LAYOUT))
 		retval = type;
 
 	/* type conversion */
-	if ((type == GNOME_DB_QF_ALL_TYPE) ||
-	    (type == GNOME_DB_QF_FIELD_TYPE) ||
-	    (type == GNOME_DB_QF_VALUE_TYPE) ||
-	    (type == GNOME_DB_QF_FUNC_TYPE))
-		retval = GNOME_DB_QFIELD_TYPE;
+	if ((type == GNOME_DB_TYPE_QF_ALL) ||
+	    (type == GNOME_DB_TYPE_QF_FIELD) ||
+	    (type == GNOME_DB_TYPE_QF_VALUE) ||
+	    (type == GNOME_DB_TYPE_QF_FUNC))
+		retval = GNOME_DB_TYPE_QFIELD;
 
 	return retval;
 }
@@ -453,25 +453,25 @@ gnome_db_ref_base_set_ref_name (GnomeDbRefBase *ref, GType ref_type, GnomeDbRefB
 			has_sep = TRUE;
 		if ((strlen (ptr) > 2) || has_sep) {
 			if ((*ptr == 'T') && (*(ptr+1) == 'V'))
-				ref_type = GNOME_DB_TABLE_TYPE;
+				ref_type = GNOME_DB_TYPE_TABLE;
 			if ((*ptr == 'F') && (*(ptr+1) == 'I'))
-				ref_type = GNOME_DB_TABLE_FIELD_TYPE;
+				ref_type = GNOME_DB_TYPE_TABLE_FIELD;
 			if ((*ptr == 'D') && (*(ptr+1) == 'T'))
-				ref_type = GNOME_DB_SERVER_DATA_TYPE_TYPE;
+				ref_type = GNOME_DB_TYPE_SERVER_DATA_TYPE;
 			if ((*ptr == 'P') && (*(ptr+1) == 'R'))
-				ref_type = GNOME_DB_SERVER_FUNCTION_TYPE;
+				ref_type = GNOME_DB_TYPE_SERVER_FUNCTION;
 			if ((*ptr == 'A') && (*(ptr+1) == 'G'))
-				ref_type = GNOME_DB_SERVER_AGGREGATE_TYPE;
+				ref_type = GNOME_DB_TYPE_SERVER_AGGREGATE;
 			if ((*ptr == 'Q') && (*(ptr+1) == 'U'))
-				ref_type = GNOME_DB_QUERY_TYPE;
+				ref_type = GNOME_DB_TYPE_QUERY;
 			if ((*ptr == 'Q') && (*(ptr+1) == 'F'))
-				ref_type = GNOME_DB_QFIELD_TYPE;
+				ref_type = GNOME_DB_TYPE_QFIELD;
 			if (has_sep && (*ptr == 'T'))
-				ref_type = GNOME_DB_TARGET_TYPE;
+				ref_type = GNOME_DB_TYPE_TARGET;
 			if (has_sep && (*ptr == 'C'))
-				ref_type = GNOME_DB_CONDITION_TYPE;
+				ref_type = GNOME_DB_TYPE_CONDITION;
 			if ((*ptr == 'C') && (*(ptr+1) == 'L'))
-				ref_type = GNOME_DB_CUSTOM_LAYOUT_TYPE;
+				ref_type = GNOME_DB_TYPE_CUSTOM_LAYOUT;
 		}
 		g_free (str);
 	}
@@ -687,7 +687,7 @@ gnome_db_ref_base_activate (GnomeDbRefBase *ref)
 
 	/* Find the object */
 	/* TABLE */
-	if (!done && (ref->priv->requested_type == GNOME_DB_TABLE_TYPE)) {
+	if (!done && (ref->priv->requested_type == GNOME_DB_TYPE_TABLE)) {
 		GnomeDbDatabase *db;
 		GnomeDbTable *table;
 
@@ -703,7 +703,7 @@ gnome_db_ref_base_activate (GnomeDbRefBase *ref)
 	}
 
 	/* TABLE's FIELD */
-	if (!done && (ref->priv->requested_type == GNOME_DB_TABLE_FIELD_TYPE)) {
+	if (!done && (ref->priv->requested_type == GNOME_DB_TYPE_TABLE_FIELD)) {
 		GnomeDbDatabase *db;
 		GnomeDbTableField *field;
 
@@ -719,7 +719,7 @@ gnome_db_ref_base_activate (GnomeDbRefBase *ref)
 	}
 
 	/* QUERY */
-	if (!done && (ref->priv->requested_type == GNOME_DB_QUERY_TYPE)) {
+	if (!done && (ref->priv->requested_type == GNOME_DB_TYPE_QUERY)) {
 		GnomeDbQuery *query = NULL;
 
 		done = TRUE;
@@ -732,7 +732,7 @@ gnome_db_ref_base_activate (GnomeDbRefBase *ref)
 	}
 
 	/* QUERY's FIELD */
-	if (!done && (ref->priv->requested_type == GNOME_DB_QFIELD_TYPE)) {
+	if (!done && (ref->priv->requested_type == GNOME_DB_TYPE_QFIELD)) {
 		GnomeDbQuery *query;
 		gchar *str, *ptr, *tok;
 
@@ -753,7 +753,7 @@ gnome_db_ref_base_activate (GnomeDbRefBase *ref)
 
 
 	/* TARGET */
-	if (!done && (ref->priv->requested_type == GNOME_DB_TARGET_TYPE)) {
+	if (!done && (ref->priv->requested_type == GNOME_DB_TYPE_TARGET)) {
 		done = TRUE;
 
 		if (ref->priv->ref_type == REFERENCE_BY_XML_ID) {
@@ -777,7 +777,7 @@ gnome_db_ref_base_activate (GnomeDbRefBase *ref)
 	}
 	
 	/* Generic FIELD (GnomeDbField interface)*/
-	if (!done && (ref->priv->requested_type == GNOME_DB_FIELD_TYPE)) {
+	if (!done && (ref->priv->requested_type == GNOME_DB_TYPE_FIELD)) {
 		if (ref->priv->ref_type == REFERENCE_BY_XML_ID) {
 			gchar *str, *ptr, *tok;
 			str = g_strdup (ref->priv->name);
@@ -820,7 +820,7 @@ gnome_db_ref_base_activate (GnomeDbRefBase *ref)
 	}
 
 	/* Server function */
-	if (!done && (ref->priv->requested_type == GNOME_DB_SERVER_FUNCTION_TYPE)) {
+	if (!done && (ref->priv->requested_type == GNOME_DB_TYPE_SERVER_FUNCTION)) {
 		GnomeDbServerFunction *func = NULL;
 		GnomeDbServer *srv;
 
@@ -835,7 +835,7 @@ gnome_db_ref_base_activate (GnomeDbRefBase *ref)
 	}
 
 	/* Server aggregate */
-	if (!done && (ref->priv->requested_type == GNOME_DB_SERVER_AGGREGATE_TYPE)) {
+	if (!done && (ref->priv->requested_type == GNOME_DB_TYPE_SERVER_AGGREGATE)) {
 		GnomeDbServerAggregate *agg = NULL;
 		GnomeDbServer *srv;
 
@@ -850,7 +850,7 @@ gnome_db_ref_base_activate (GnomeDbRefBase *ref)
 	}
 
 	/* Custom Layout */
-	if (!done && (ref->priv->requested_type == GNOME_DB_CUSTOM_LAYOUT_TYPE)) {
+	if (!done && (ref->priv->requested_type == GNOME_DB_TYPE_CUSTOM_LAYOUT)) {
 		GnomeDbCustomLayout *layout = NULL;
 
 		done = TRUE;
