@@ -151,7 +151,7 @@ gnome_db_selector_new (GnomeDbDict *dict, GObject *ref_object, gulong mode, gulo
 
 	g_return_val_if_fail (!dict || IS_GNOME_DB_DICT (dict), NULL);
 		
-	obj = g_object_new (GNOME_DB_SELECTOR_TYPE, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_SELECTOR, NULL);
 	mgsel = GNOME_DB_SELECTOR (obj);
 
 	mgsel->priv->dict = ASSERT_DICT (dict);
