@@ -25,6 +25,7 @@
 #include "marshal.h"
 #include <libgda/libgda.h>
 #include <string.h>
+#include "utility.h"
 
 /* 
  * Main static functions 
@@ -113,8 +114,8 @@ gnome_db_server_data_type_get_type (void)
 			NULL
 		};
 		
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbServerDataType", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_XML_STORAGE_TYPE, &xml_storage_info);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbServerDataType", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_XML_STORAGE, &xml_storage_info);
 	}
 	return type;
 }
@@ -181,7 +182,7 @@ gnome_db_server_data_type_new (GnomeDbServer *srv)
 
 	g_return_val_if_fail (srv && GNOME_DB_SERVER (srv), NULL);
 
-	obj = g_object_new (GNOME_DB_SERVER_DATA_TYPE_TYPE, "dict",
+	obj = g_object_new (GNOME_DB_TYPE_SERVER_DATA_TYPE, "dict",
 			    gnome_db_server_get_dict (srv), NULL);
 	gnome_db_server_data_type = GNOME_DB_SERVER_DATA_TYPE (obj);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_server_data_type), 0);
@@ -274,24 +275,14 @@ gnome_db_server_data_type_get_property (GObject              *object,
 	}
 }
 
-
 /* GnomeDbXmlStorage interface implementation */
 static gchar *
 gnome_db_data_type_get_xml_id (GnomeDbXmlStorage *iface)
 {
-	gchar *retval, *ptr;
 	g_return_val_if_fail (iface && IS_GNOME_DB_SERVER_DATA_TYPE (iface), NULL);
 	g_return_val_if_fail (GNOME_DB_SERVER_DATA_TYPE (iface)->priv, NULL);
 
-	retval = g_strdup_printf ("DT%s", gnome_db_base_get_name (GNOME_DB_BASE (iface)));
-	ptr = retval;
-
-	while (*ptr) {
-		if (*ptr == ' ')
-			*ptr = '_';
-		ptr++;
-	}
-	return retval;
+	return utility_build_encoded_id ("DT", gnome_db_base_get_name (GNOME_DB_BASE (iface)));
 }
 
 static xmlNodePtr
