@@ -30,6 +30,7 @@
 #include "gnome-db-server-data-type.h"
 #include "gnome-db-constraint.h"
 #include <string.h>
+#include "utility.h"
 
 /* 
  * Main static functions 
@@ -78,15 +79,6 @@ static GnomeDbDataHandler *gnome_db_table_field_handler_func (GnomeDbServer *srv
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass  *parent_class = NULL;
 
-/* signals */
-enum
-{
-	TEMPL_SIGNAL,
-	LAST_SIGNAL
-};
-
-static gint gnome_db_table_field_signals[LAST_SIGNAL] = { 0 };
-
 /* properties */
 enum
 {
@@ -99,10 +91,11 @@ enum
 struct _GnomeDbTableFieldPrivate
 {
 	GnomeDbServerDataType *data_type;
-	GnomeDbTable        *table;
-	gint              length;     /* -1 if not applicable */
-	gint              scale;      /* 0 if not applicable */
-	GdaValue         *default_val;/* NULL if no default value */
+	GnomeDbTable          *table;
+	gint                   length;     /* -1 if not applicable */
+	gint                   scale;      /* 0 if not applicable */
+	GdaValue              *default_val;/* NULL if no default value */
+	guint                  extra_attrs;/* OR'ed value of GnomeDbTableFieldAttribute */
 };
 #define FIELD_SRV(field) (gnome_db_dict_get_server (gnome_db_base_get_dict (GNOME_DB_BASE (field))))
 
@@ -154,10 +147,10 @@ gnome_db_table_field_get_type (void)
 		};
 		
 		
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbTableField", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_XML_STORAGE_TYPE, &xml_storage_info);
-		g_type_add_interface_static (type, GNOME_DB_FIELD_TYPE, &field_info);
-		g_type_add_interface_static (type, GNOME_DB_RENDERER_TYPE, &renderer_info);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbTableField", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_XML_STORAGE, &xml_storage_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_FIELD, &field_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_RENDERER, &renderer_info);
 	}
 	return type;
 }
@@ -193,16 +186,6 @@ gnome_db_table_field_class_init (GnomeDbTableFieldClass * class)
 
 	parent_class = g_type_class_peek_parent (class);
 
-	gnome_db_table_field_signals[TEMPL_SIGNAL] =
-		g_signal_new ("templ_signal",
-			      G_TYPE_FROM_CLASS (object_class),
-			      G_SIGNAL_RUN_FIRST,
-			      G_STRUCT_OFFSET (GnomeDbTableFieldClass, templ_signal),
-			      NULL, NULL,
-			      marshal_VOID__VOID, G_TYPE_NONE,
-			      0);
-	class->templ_signal = NULL;
-
 	object_class->dispose = gnome_db_table_field_dispose;
 	object_class->finalize = gnome_db_table_field_finalize;
 
@@ -228,6 +211,7 @@ gnome_db_table_field_init (GnomeDbTableField * gnome_db_table_field)
 	gnome_db_table_field->priv->data_type = NULL;
 	gnome_db_table_field->priv->length = -1;
 	gnome_db_table_field->priv->scale = 0;
+	gnome_db_table_field->priv->extra_attrs = 0;
 }
 
 
@@ -250,7 +234,7 @@ gnome_db_table_field_new (GnomeDbDict *dict, GnomeDbServerDataType *type)
 	if (type)
 		g_return_val_if_fail (IS_GNOME_DB_SERVER_DATA_TYPE (type), NULL);
 
-	obj = g_object_new (GNOME_DB_TABLE_FIELD_TYPE, "dict", ASSERT_DICT (dict), NULL);
+	obj = g_object_new (GNOME_DB_TYPE_TABLE_FIELD, "dict", ASSERT_DICT (dict), NULL);
 	gnome_db_table_field = GNOME_DB_TABLE_FIELD (obj);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_table_field), 0);
 
@@ -556,6 +540,14 @@ gnome_db_table_field_get_default_value (GnomeDbTableField *field)
 	return field->priv->default_val;
 }
 
+/**
+ * gnome_db_table_field_is_null_allowed
+ * @field: a #GnomeDbTableField object
+ *
+ * Test if @field can be %NULL or not
+ *
+ * Returns:
+ */
 gboolean
 gnome_db_table_field_is_null_allowed (GnomeDbTableField *field)
 {
@@ -579,6 +571,14 @@ gnome_db_table_field_is_null_allowed (GnomeDbTableField *field)
 	return retval;
 }
 
+/**
+ * gnome_db_table_field_is_pkey_part
+ * @field: a #GnomeDbTableField object
+ *
+ * Test if @field is part of a primary key constraint
+ *
+ * Returns:
+ */
 gboolean
 gnome_db_table_field_is_pkey_part (GnomeDbTableField *field)
 {
@@ -602,6 +602,14 @@ gnome_db_table_field_is_pkey_part (GnomeDbTableField *field)
 	return retval;
 }
 
+/**
+ * gnome_db_table_field_is_pkey_alone
+ * @field: a #GnomeDbTableField object
+ *
+ * Test if @field is alone a primary key constraint
+ *
+ * Returns:
+ */
 gboolean
 gnome_db_table_field_is_pkey_alone (GnomeDbTableField *field)
 {
@@ -628,6 +636,14 @@ gnome_db_table_field_is_pkey_alone (GnomeDbTableField *field)
 	return retval;
 }
 
+/**
+ * gnome_db_table_field_is_fkey_part
+ * @field: a #GnomeDbTableField object
+ *
+ * Test if @field is part of a foreign key constraint
+ *
+ * Returns:
+ */
 gboolean
 gnome_db_table_field_is_fkey_part (GnomeDbTableField *field)
 {
@@ -651,6 +667,14 @@ gnome_db_table_field_is_fkey_part (GnomeDbTableField *field)
 	return retval;
 }
 
+/**
+ * gnome_db_table_field_is_fkey_alone
+ * @field: a #GnomeDbTableField object
+ *
+ * Test if @field is alone a foreign key constraint
+ *
+ * Returns:
+ */
 gboolean
 gnome_db_table_field_is_fkey_alone (GnomeDbTableField *field)
 {
@@ -684,6 +708,42 @@ gnome_db_table_field_is_fkey_alone (GnomeDbTableField *field)
 	return retval;	
 }
 
+/**
+ * gnome_db_table_field_is_fkey_alone
+ * @field: a #GnomeDbTableField object
+ * @attributes: the new attributes value
+ *
+ * Sets @field's extra attributes. The @attributes is an OR'ed value of all the possible
+ * values in #GnomeDbTableFieldAttribute.
+ */
+void
+gnome_db_table_field_set_attributes (GnomeDbTableField *field, guint attributes)
+{
+	g_return_if_fail (field && IS_GNOME_DB_TABLE_FIELD (field));
+	g_return_if_fail (field->priv);
+
+	field->priv->extra_attrs = attributes;
+}
+
+/**
+ * gnome_db_table_field_is_fkey_alone
+ * @field: a #GnomeDbTableField object
+ *
+ * Get @field's extra attributes. The @attributes is an OR'ed value of all the possible
+ * values in #GnomeDbTableFieldAttribute.
+ *
+ * Returns: the new attributes value
+ */
+guint
+gnome_db_table_field_get_attributes (GnomeDbTableField *field)
+{
+	g_return_val_if_fail (field && IS_GNOME_DB_TABLE_FIELD (field), 0);
+	g_return_val_if_fail (field->priv, 0);
+
+	return field->priv->extra_attrs;
+}
+
+
 #ifdef debug
 static void
 gnome_db_table_field_dump (GnomeDbTableField *field, guint offset)
@@ -736,14 +796,16 @@ gnome_db_table_field_get_data_type (GnomeDbField *iface)
 static gchar *
 gnome_db_table_field_get_xml_id (GnomeDbXmlStorage *iface)
 {
-	gchar *t_xml_id, *xml_id;
+	gchar *t_xml_id, *tmp, *xml_id;
 
 	g_return_val_if_fail (iface && IS_GNOME_DB_TABLE_FIELD (iface), NULL);
 	g_return_val_if_fail (GNOME_DB_TABLE_FIELD (iface)->priv, NULL);
 
 	t_xml_id = gnome_db_xml_storage_get_xml_id (GNOME_DB_XML_STORAGE (GNOME_DB_TABLE_FIELD (iface)->priv->table));
-	xml_id = g_strdup_printf ("%s:FI%s", t_xml_id, gnome_db_base_get_name (GNOME_DB_BASE (iface)));
+	tmp = utility_build_encoded_id ("FI", gnome_db_base_get_name (GNOME_DB_BASE (iface)));
+	xml_id = g_strconcat (t_xml_id, ":", tmp, NULL);
 	g_free (t_xml_id);
+	g_free (tmp);
 	
 	return xml_id;
 }
@@ -792,6 +854,12 @@ gnome_db_table_field_save_to_xml (GnomeDbXmlStorage *iface, GError **error)
 		g_free (str);
 	}
 
+	str = utility_table_field_attrs_stringify (field->priv->extra_attrs);
+	if (str) {
+		xmlSetProp (node, "extra_attr", str);
+		g_free (str);
+	}
+
 	if (gnome_db_server_object_has_handler (FIELD_SRV (field), G_OBJECT (field))) {
 		GnomeDbDataHandler *dh;
 		dh = gnome_db_server_get_object_handler (FIELD_SRV (field), G_OBJECT (field));
@@ -849,10 +917,13 @@ gnome_db_table_field_load_from_xml (GnomeDbXmlStorage *iface, xmlNodePtr node, G
 			else {
 				/* create a new custom data type */
 				GnomeDbServer *srv;
+				gchar *tmp;
 				
 				srv = gnome_db_dict_get_server (gnome_db_base_get_dict (GNOME_DB_BASE (field)));
 				dt = GNOME_DB_SERVER_DATA_TYPE (gnome_db_server_data_type_new (srv));
-				gnome_db_server_data_type_set_sqlname (dt, prop + 2);
+				tmp = utility_build_decoded_id (NULL, prop + 2);
+				gnome_db_server_data_type_set_sqlname (dt, tmp);
+				g_free (tmp);
 				gnome_db_server_data_type_set_gda_type (dt, GDA_VALUE_TYPE_BLOB);
 				gnome_db_base_set_description (GNOME_DB_BASE (dt), _("Custom data type"));
 				gnome_db_server_declare_custom_data_type (srv, dt);
@@ -906,7 +977,12 @@ gnome_db_table_field_load_from_xml (GnomeDbXmlStorage *iface, xmlNodePtr node, G
 		g_free (prop);
 	}
 
-
+	prop = xmlGetProp (node, "extra_attr");
+	if (prop) {
+		gnome_db_table_field_set_attributes (field, 
+						     utility_table_field_attrs_parse (prop));
+		g_free (prop);
+	}
 
 	if (name && type)
 		return TRUE;
