@@ -32,6 +32,7 @@
 #include "gnome-db-result-set.h"
 #include <string.h>
 #include "gnome-db-ref-base.h"
+#include "utility.h"
 
 /* 
  * Main static functions 
@@ -160,9 +161,9 @@ gnome_db_table_get_type (void)
 			NULL
 		};
 		
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbTable", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_XML_STORAGE_TYPE, &xml_storage_info);
-		g_type_add_interface_static (type, GNOME_DB_ENTITY_TYPE, &entity_info);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbTable", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_XML_STORAGE, &xml_storage_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_ENTITY, &entity_info);
 	}
 	return type;
 }
@@ -253,7 +254,7 @@ gnome_db_table_new (GnomeDbDict *dict)
 
 	g_return_val_if_fail (!dict || IS_GNOME_DB_DICT (dict), NULL);
 
-	obj = g_object_new (GNOME_DB_TABLE_TYPE, "dict", ASSERT_DICT (dict), NULL);
+	obj = g_object_new (GNOME_DB_TYPE_TABLE, "dict", ASSERT_DICT (dict), NULL);
 	gnome_db_table = GNOME_DB_TABLE (obj);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_table), 0);
 
@@ -565,6 +566,7 @@ gnome_db_table_update_dbms_data (GnomeDbTable *table, GError **error)
 	gint current_position = 0;
 	GSList *constraints;
 	GHashTable *fk_hash;
+	gboolean has_extra_attributes = FALSE;
 	
 	g_return_val_if_fail (table && IS_GNOME_DB_TABLE (table), FALSE);
 	g_return_val_if_fail (GNOME_DB_TABLE (table)->priv, FALSE);
@@ -613,13 +615,29 @@ gnome_db_table_update_dbms_data (GnomeDbTable *table, GError **error)
 						   GDA_VALUE_TYPE_BOOLEAN,
 						   GDA_VALUE_TYPE_BOOLEAN,
 						   GDA_VALUE_TYPE_BOOLEAN,
-						   GDA_VALUE_TYPE_STRING, -1)) {
+						   GDA_VALUE_TYPE_STRING, 
+						   -1)) {
 		g_set_error (error, GNOME_DB_TABLE_ERROR, GNOME_DB_TABLE_FIELDS_ERROR,
 			     _("Schema for list of fields is wrong"));
 		g_object_unref (G_OBJECT (rs));
 		return FALSE;
 	}
 
+	if (gda_data_model_get_n_columns (GDA_DATA_MODEL (rs)) == 10) {
+		GdaColumn *att;
+		att = gda_data_model_describe_column (GDA_DATA_MODEL (rs), 9);
+		
+		if (gda_column_get_gdatype (att) != GDA_VALUE_TYPE_STRING) {
+			gda_column_free (att);
+			g_set_error (error, GNOME_DB_TABLE_ERROR, GNOME_DB_TABLE_FIELDS_ERROR,
+				     _("Schema for list of fields is wrong"));
+			g_object_unref (G_OBJECT (rs));
+		}
+
+		gda_column_free (att);
+		has_extra_attributes = TRUE;
+	}
+
 	/* Resultset parsing */
 	total = gda_data_model_get_n_rows (rs);
 	now = 0;		
@@ -720,6 +738,26 @@ gnome_db_table_update_dbms_data (GnomeDbTable *table, GError **error)
 			gnome_db_constraint_not_null_set_field (cstr, field);
 			constraints = g_slist_append (constraints, cstr);
 		}
+		else {
+			/* remove the constraint */
+			GnomeDbConstraint *cstr = NULL;
+			GSList *list, *table_cons;
+			
+			/* find NOT NULL constraint */
+			table_cons = gnome_db_table_get_constraints (table);
+			list = table_cons;
+			while (list && !cstr) {
+				if ((gnome_db_constraint_get_constraint_type (GNOME_DB_CONSTRAINT (list->data))==CONSTRAINT_NOT_NULL) &&
+				    gnome_db_constraint_uses_field (GNOME_DB_CONSTRAINT (list->data), field))
+					cstr = GNOME_DB_CONSTRAINT (list->data);
+				list = g_slist_next (list);
+			}
+			g_slist_free (table_cons);
+
+			if (cstr) 
+				/* remove that constraint */
+				gnome_db_base_nullify (GNOME_DB_BASE (cstr));
+		}
 
 		/* Other constraints:
 		 * For constraints other than the NOT NULL constraint, this is a temporary solution to
@@ -787,7 +825,7 @@ gnome_db_table_update_dbms_data (GnomeDbTable *table, GError **error)
 			g_free (str);
 			
 			ref = GNOME_DB_REF_BASE (gnome_db_ref_base_new (gnome_db_base_get_dict (GNOME_DB_BASE (table))));
-			gnome_db_ref_base_set_ref_name (ref, GNOME_DB_TABLE_FIELD_TYPE, 
+			gnome_db_ref_base_set_ref_name (ref, GNOME_DB_TYPE_TABLE_FIELD, 
 						  REFERENCE_BY_NAME, gda_value_get_string (value));
 			
 			/* find the foreign key constraint if it already exists */
@@ -817,6 +855,14 @@ gnome_db_table_update_dbms_data (GnomeDbTable *table, GError **error)
 			g_object_unref (G_OBJECT (ref));
 			g_slist_free (nlist);
 		}
+
+		/* EXTRA attributes if supported by the schema */
+		if (has_extra_attributes) {
+			value = gda_data_model_get_value_at (rs, 9, now);
+			
+			gnome_db_table_field_set_attributes (field, 
+							     utility_table_field_attrs_parse (gda_value_get_string (value)));
+		}
 		
 		now++;
 	}
@@ -1098,7 +1144,7 @@ gnome_db_table_get_xml_id (GnomeDbXmlStorage *iface)
 	g_return_val_if_fail (iface && IS_GNOME_DB_TABLE (iface), NULL);
 	g_return_val_if_fail (GNOME_DB_TABLE (iface)->priv, NULL);
 
-	return g_strdup_printf ("TV%s", gnome_db_base_get_name (GNOME_DB_BASE (iface)));
+	return utility_build_encoded_id ("TV", gnome_db_base_get_name (GNOME_DB_BASE (iface)));
 }
 
 static xmlNodePtr
