@@ -1,6 +1,6 @@
 /* gnome-db-target.c
  *
- * Copyright (C) 2003 - 2004 Vivien Malerba
+ * Copyright (C) 2003 - 2005 Vivien Malerba
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -27,6 +27,7 @@
 #include "gnome-db-renderer.h"
 #include "gnome-db-query.h"
 #include "gnome-db-table.h"
+#include "gnome-db-server.h"
 
 /* 
  * Main static functions 
@@ -93,7 +94,7 @@ struct _GnomeDbTargetPrivate
 {
 	GnomeDbQuery    *query;
 	GnomeDbRefBase  *entity_ref;
-	gchar      *alias;
+	gchar           *alias;
 };
 
 
@@ -143,10 +144,10 @@ gnome_db_target_get_type (void)
 			NULL
 		};
 		
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbTarget", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_XML_STORAGE_TYPE, &xml_storage_info);
-		g_type_add_interface_static (type, GNOME_DB_REFERER_TYPE, &referer_info);
-		g_type_add_interface_static (type, GNOME_DB_RENDERER_TYPE, &renderer_info);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbTarget", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_XML_STORAGE, &xml_storage_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_REFERER, &referer_info);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_RENDERER, &renderer_info);
 	}
 	return type;
 }
@@ -231,7 +232,7 @@ gnome_db_target_new_with_entity (GnomeDbQuery *query, GnomeDbEntity *entity)
 	g_return_val_if_fail (entity && IS_GNOME_DB_ENTITY (entity), NULL);
 
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (query));
-	obj = g_object_new (GNOME_DB_TARGET_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_TARGET, "dict", dict, NULL);
 	gnome_db_target = GNOME_DB_TARGET (obj);
 	g_object_get (G_OBJECT (query), "target_serial", &id, NULL);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_target), id);
@@ -268,7 +269,7 @@ gnome_db_target_new_with_xml_id (GnomeDbQuery *query, const gchar *entity_xml_id
 	g_return_val_if_fail (entity_xml_id && *entity_xml_id, NULL);
 
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (query));
-	obj = g_object_new (GNOME_DB_TARGET_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_TARGET, "dict", dict, NULL);
 	gnome_db_target = GNOME_DB_TARGET (obj);
 	g_object_get (G_OBJECT (query), "target_serial", &id, NULL);
 	gnome_db_base_set_id (GNOME_DB_BASE (gnome_db_target), id);
@@ -279,9 +280,9 @@ gnome_db_target_new_with_xml_id (GnomeDbQuery *query, const gchar *entity_xml_id
 
 	gnome_db_target->priv->entity_ref = GNOME_DB_REF_BASE (gnome_db_ref_base_new (dict));
 	if (*entity_xml_id == 'T') 
-		target_ref = GNOME_DB_TABLE_TYPE;
+		target_ref = GNOME_DB_TYPE_TABLE;
 	else
-		target_ref = GNOME_DB_QUERY_TYPE;
+		target_ref = GNOME_DB_TYPE_QUERY;
 	gnome_db_ref_base_set_ref_name (gnome_db_target->priv->entity_ref, target_ref, REFERENCE_BY_XML_ID, entity_xml_id);
 
 	return obj;
@@ -306,7 +307,7 @@ gnome_db_target_new_copy (GnomeDbTarget *orig)
 	g_return_val_if_fail (orig && IS_GNOME_DB_TARGET (orig), NULL);
 
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (orig));
-	obj = g_object_new (GNOME_DB_TARGET_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_TARGET, "dict", dict, NULL);
 	gnome_db_target = GNOME_DB_TARGET (obj);
 
 	gnome_db_target->priv->query = orig->priv->query;
@@ -753,9 +754,9 @@ gnome_db_target_load_from_xml (GnomeDbXmlStorage *iface, xmlNodePtr node, GError
 			GnomeDbBase *base;
 
 			if (*str == 'T') 
-				target_ref = GNOME_DB_TABLE_TYPE;
+				target_ref = GNOME_DB_TYPE_TABLE;
 			else
-				target_ref = GNOME_DB_QUERY_TYPE;
+				target_ref = GNOME_DB_TYPE_QUERY;
 			gnome_db_ref_base_set_ref_name (target->priv->entity_ref, target_ref, 
 						  REFERENCE_BY_XML_ID, str);
 			
@@ -835,7 +836,14 @@ gnome_db_target_render_as_sql (GnomeDbRenderer *iface, GnomeDbDataSet *context,
 	if (string) {
 		if (!err) {
 			/* adding alias */
-			g_string_append (string, " AS ");
+			GnomeDbServerInfo *info;
+
+			info = gnome_db_server_get_server_info (gnome_db_dict_get_server 
+								(gnome_db_base_get_dict (GNOME_DB_BASE (target))));
+			if (!info || (info->alias_needs_as_keyword))
+				g_string_append (string, " AS ");
+			else
+				g_string_append_c (string, ' ');
 			g_string_append (string, gnome_db_target_get_alias (target));
 			
 			str = string->str;
