@@ -71,7 +71,7 @@ struct _GnomeDbCanvasEntityPrivate
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass *entity_parent_class = NULL;
 
-guint
+GType
 gnome_db_canvas_entity_get_type (void)
 {
 	static GType type = 0;
@@ -89,7 +89,7 @@ gnome_db_canvas_entity_get_type (void)
 			(GInstanceInitFunc) gnome_db_canvas_entity_init
 		};		
 
-		type = g_type_register_static (GNOME_DB_CANVAS_ITEM_TYPE, "GnomeDbCanvasEntity", &info, 0);
+		type = g_type_register_static (GNOME_DB_TYPE_CANVAS_ITEM, "GnomeDbCanvasEntity", &info, 0);
 	}
 
 	return type;
@@ -386,7 +386,7 @@ create_items (GnomeDbCanvasEntity *ce)
 	fieldn = 0;
 	while (tmplist) {
 		item = gnome_canvas_item_new (GNOME_CANVAS_GROUP (ce),
-					      GNOME_DB_CANVAS_FIELD_TYPE,
+					      GNOME_DB_TYPE_CANVAS_FIELD,
 					      "x", 0.,
 					      "y", ce->priv->field_ypos[fieldn],
 					      "field", tmplist->data,
