@@ -73,7 +73,7 @@ gnome_db_canvas_field_get_type (void)
 			(GInstanceInitFunc) gnome_db_canvas_field_init
 		};		
 
-		type = g_type_register_static (GNOME_DB_CANVAS_TEXT_TYPE, "GnomeDbCanvasField", &info, 0);
+		type = g_type_register_static (GNOME_DB_TYPE_CANVAS_TEXT, "GnomeDbCanvasField", &info, 0);
 	}
 
 	return type;
