@@ -33,7 +33,7 @@ G_BEGIN_DECLS
  *
  */
 
-#define GNOME_DB_CANVAS_FIELD_TYPE          (gnome_db_canvas_field_get_type())
+#define GNOME_DB_TYPE_CANVAS_FIELD          (gnome_db_canvas_field_get_type())
 #define GNOME_DB_CANVAS_FIELD(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_canvas_field_get_type(), GnomeDbCanvasField)
 #define GNOME_DB_CANVAS_FIELD_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_canvas_field_get_type (), GnomeDbCanvasFieldClass)
 #define IS_GNOME_DB_CANVAS_FIELD(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_canvas_field_get_type ())
