@@ -87,7 +87,7 @@ gnome_db_canvas_query_struct_get_type (void)
 			(GInstanceInitFunc) gnome_db_canvas_query_struct_init
 		};		
 
-		type = g_type_register_static (GNOME_DB_CANVAS_TYPE, "GnomeDbCanvasQueryStruct", &info, 0);
+		type = g_type_register_static (GNOME_DB_TYPE_CANVAS, "GnomeDbCanvasQueryStruct", &info, 0);
 	}
 	return type;
 }
@@ -294,7 +294,7 @@ gnome_db_canvas_query_struct_new (GnomeDbQuery *query, GnomeDbGraph *graph)
 		g_return_val_if_fail (gnome_db_base_get_dict (GNOME_DB_BASE (query)) == gnome_db_base_get_dict (GNOME_DB_BASE (graph)), NULL);
 	}
 
-        obj = g_object_new (GNOME_DB_CANVAS_QUERY_STRUCT_TYPE, "aa", FALSE, NULL);
+        obj = g_object_new (GNOME_DB_TYPE_CANVAS_QUERY_STRUCT, "aa", FALSE, NULL);
 	gnome_canvas_set_center_scroll_region (GNOME_CANVAS (obj), TRUE);
 	canvas = GNOME_DB_CANVAS_QUERY_STRUCT (obj);
 
@@ -345,7 +345,7 @@ query_join_added_cb (GnomeDbQuery *query, GnomeDbJoin *join, GnomeDbCanvas *canv
 	g_return_if_fail (!canvas_join);
 		
 	canvas_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP (root),
-					     GNOME_DB_CANVAS_JOIN_TYPE,
+					     GNOME_DB_TYPE_CANVAS_JOIN,
 					     "join", join,
 					     NULL);
 		
@@ -399,7 +399,7 @@ graph_item_added (GnomeDbCanvas *canvas, GnomeDbGraphItem *item)
 	if (IS_GNOME_DB_TARGET (ref_obj)) {
 		/* GnomeDbCanvasEntity for the table */
 		canvas_item = gnome_canvas_item_new (GNOME_CANVAS_GROUP (root),
-						     GNOME_DB_CANVAS_ENTITY_TYPE,
+						     GNOME_DB_TYPE_CANVAS_ENTITY,
 						     "popup_menu_func", canvas_entity_popup_func,
 						     "target", ref_obj,
 						     "x", 50.,
