@@ -33,7 +33,7 @@ G_BEGIN_DECLS
  *
  */
 
-#define GNOME_DB_CANVAS_TIP_TYPE          (gnome_db_canvas_tip_get_type())
+#define GNOME_DB_TYPE_CANVAS_TIP          (gnome_db_canvas_tip_get_type())
 #define GNOME_DB_CANVAS_TIP(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_canvas_tip_get_type(), GnomeDbCanvasTip)
 #define GNOME_DB_CANVAS_TIP_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_canvas_tip_get_type (), GnomeDbCanvasTipClass)
 #define IS_GNOME_DB_CANVAS_TIP(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_canvas_tip_get_type ())
