@@ -62,7 +62,7 @@ gnome_db_graph_query_get_type (void)
 			(GInstanceInitFunc) gnome_db_graph_query_init
 		};
 
-		type = g_type_register_static (GNOME_DB_GRAPH_TYPE, "GnomeDbGraphQuery", &info, 0);
+		type = g_type_register_static (GNOME_DB_TYPE_GRAPH, "GnomeDbGraphQuery", &info, 0);
 	}
 	return type;
 }
@@ -111,7 +111,7 @@ gnome_db_graph_query_new (GnomeDbQuery *query)
 	g_return_val_if_fail (query && IS_GNOME_DB_QUERY (query), NULL);
 	dict = gnome_db_base_get_dict (GNOME_DB_BASE (query));
 
-	obj = g_object_new (GNOME_DB_GRAPH_QUERY_TYPE, "dict", dict, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_GRAPH_QUERY, "dict", dict, NULL);
 	graph = GNOME_DB_GRAPH_QUERY (obj);
 
 	g_object_get (G_OBJECT (dict), "graph_serial", &id, NULL);
