@@ -26,7 +26,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_GRAPH_QUERY_TYPE          (gnome_db_graph_query_get_type())
+#define GNOME_DB_TYPE_GRAPH_QUERY          (gnome_db_graph_query_get_type())
 #define GNOME_DB_GRAPH_QUERY(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_graph_query_get_type(), GnomeDbGraphQuery)
 #define GNOME_DB_GRAPH_QUERY_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_graph_query_get_type (), GnomeDbGraphQueryClass)
 #define IS_GNOME_DB_GRAPH_QUERY(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_graph_query_get_type ())
