@@ -29,7 +29,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_GRAPH_TYPE          (gnome_db_graph_get_type())
+#define GNOME_DB_TYPE_GRAPH          (gnome_db_graph_get_type())
 #define GNOME_DB_GRAPH(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_graph_get_type(), GnomeDbGraph)
 #define GNOME_DB_GRAPH_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_graph_get_type (), GnomeDbGraphClass)
 #define IS_GNOME_DB_GRAPH(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_graph_get_type ())
