@@ -110,7 +110,7 @@ struct  _GnomeDbEntryComboPriv {
 /* get a pointer to the parents to be able to call their destructor */
 static GObjectClass *parent_class = NULL;
 
-guint
+GType
 gnome_db_entry_combo_get_type (void)
 {
 	static GType type = 0;
@@ -134,8 +134,8 @@ gnome_db_entry_combo_get_type (void)
 			NULL
 		};
 
-		type = g_type_register_static (GNOME_DB_ENTRY_SHELL_TYPE, "GnomeDbEntryCombo", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_DATA_ENTRY_TYPE, &data_entry_info);
+		type = g_type_register_static (GNOME_DB_TYPE_ENTRY_SHELL, "GnomeDbEntryCombo", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_DATA_ENTRY, &data_entry_info);
 	}
 	return type;
 }
@@ -246,7 +246,7 @@ gnome_db_entry_combo_new (GnomeDbDataSet *data_set, GnomeDbDataSetNode *node)
 	g_return_val_if_fail (node->params, NULL);
 	g_return_val_if_fail (node->data_for_param && IS_GNOME_DB_DATA_MODEL (node->data_for_param), NULL);
 
-	obj = g_object_new (GNOME_DB_ENTRY_COMBO_TYPE, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_ENTRY_COMBO, NULL);
 	combo = GNOME_DB_ENTRY_COMBO (obj);
 
 	g_object_ref (node->data_for_param);
