@@ -105,7 +105,7 @@ gnome_db_entry_string_get_type (void)
 			NULL                                                  /* interface_data */
 		};
 		
-		type = g_type_register_static (GNOME_DB_ENTRY_WRAPPER_TYPE, "GnomeDbEntryString", &info, 0);
+		type = g_type_register_static (GNOME_DB_TYPE_ENTRY_WRAPPER, "GnomeDbEntryString", &info, 0);
 		g_type_add_interface_static (type, GTK_TYPE_CELL_EDITABLE, &cell_editable_info);
 	}
 	return type;
@@ -169,7 +169,7 @@ gnome_db_entry_string_new (GnomeDbDataHandler *dh, GdaValueType type)
 	g_return_val_if_fail (type != GDA_VALUE_TYPE_UNKNOWN, NULL);
 	g_return_val_if_fail (gnome_db_data_handler_accepts_gda_type (dh, type), NULL);
 
-	obj = g_object_new (GNOME_DB_ENTRY_STRING_TYPE, "handler", dh, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_ENTRY_STRING, "handler", dh, NULL);
 	mgstr = GNOME_DB_ENTRY_STRING (obj);
 	gnome_db_data_entry_set_value_type (GNOME_DB_DATA_ENTRY (mgstr), type);
 
@@ -345,7 +345,6 @@ real_set_value (GnomeDbEntryWrapper *mgwrap, const GdaValue *value)
 		g_object_set (G_OBJECT (mgwrap), "multiline", TRUE, NULL);
 	g_object_unref (G_OBJECT (layout));
 
-
 	/* fill the single line widget */
 	if (value) {
 		if (gda_value_is_null (value))
