@@ -26,7 +26,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_ENTRY_STRING_TYPE          (gnome_db_entry_string_get_type())
+#define GNOME_DB_TYPE_ENTRY_STRING          (gnome_db_entry_string_get_type())
 #define GNOME_DB_ENTRY_STRING(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_entry_string_get_type(), GnomeDbEntryString)
 #define GNOME_DB_ENTRY_STRING_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_entry_string_get_type (), GnomeDbEntryStringClass)
 #define IS_GNOME_DB_ENTRY_STRING(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_entry_string_get_type ())
