@@ -90,8 +90,8 @@ gnome_db_handler_none_get_type (void)
 			NULL
 		};
 
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbHandlerNone", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_DATA_HANDLER_TYPE, &data_entry_info);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbHandlerNone", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_DATA_HANDLER, &data_entry_info);
 	}
 	return type;
 }
@@ -180,7 +180,7 @@ gnome_db_handler_none_new (GnomeDbServer *srv)
 	GnomeDbHandlerNone *hdl;
 
 	g_return_val_if_fail (srv && IS_GNOME_DB_SERVER (srv), NULL);
-	obj = g_object_new (GNOME_DB_HANDLER_NONE_TYPE, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_HANDLER_NONE, NULL);
 	hdl = GNOME_DB_HANDLER_NONE (obj);
 
 	g_object_add_weak_pointer (G_OBJECT (srv), (gpointer *) &(hdl->priv->srv));
