@@ -27,7 +27,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_HANDLER_NUMERICAL_TYPE          (gnome_db_handler_numerical_get_type())
+#define GNOME_DB_TYPE_HANDLER_NUMERICAL          (gnome_db_handler_numerical_get_type())
 #define GNOME_DB_HANDLER_NUMERICAL(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_handler_numerical_get_type(), GnomeDbHandlerNumerical)
 #define GNOME_DB_HANDLER_NUMERICAL_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_handler_numerical_get_type (), GnomeDbHandlerNumericalClass)
 #define IS_GNOME_DB_HANDLER_NUMERICAL(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_handler_numerical_get_type ())
