@@ -27,7 +27,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_HANDLER_STRING_TYPE          (gnome_db_handler_string_get_type())
+#define GNOME_DB_TYPE_HANDLER_STRING          (gnome_db_handler_string_get_type())
 #define GNOME_DB_HANDLER_STRING(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_handler_string_get_type(), GnomeDbHandlerString)
 #define GNOME_DB_HANDLER_STRING_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_handler_string_get_type (), GnomeDbHandlerStringClass)
 #define IS_GNOME_DB_HANDLER_STRING(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_handler_string_get_type ())
