@@ -121,8 +121,8 @@ gnome_db_handler_time_get_type (void)
 			NULL
 		};
 
-		type = g_type_register_static (GNOME_DB_BASE_TYPE, "GnomeDbHandlerTime", &info, 0);
-		g_type_add_interface_static (type, GNOME_DB_DATA_HANDLER_TYPE, &data_entry_info);
+		type = g_type_register_static (GNOME_DB_TYPE_BASE, "GnomeDbHandlerTime", &info, 0);
+		g_type_add_interface_static (type, GNOME_DB_TYPE_DATA_HANDLER, &data_entry_info);
 	}
 	return type;
 }
@@ -241,7 +241,7 @@ gnome_db_handler_time_new (GnomeDbServer *srv)
 	GnomeDbHandlerTime *hdl;
 
 	g_return_val_if_fail (srv && IS_GNOME_DB_SERVER (srv), NULL);
-	obj = g_object_new (GNOME_DB_HANDLER_TIME_TYPE, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_HANDLER_TIME, NULL);
 	hdl = GNOME_DB_HANDLER_TIME (obj);
 
 	g_object_add_weak_pointer (G_OBJECT (srv), (gpointer *) &(hdl->priv->srv));
