@@ -26,7 +26,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_ENTRY_CIDR_TYPE          (gnome_db_entry_cidr_get_type())
+#define GNOME_DB_TYPE_ENTRY_CIDR          (gnome_db_entry_cidr_get_type())
 #define GNOME_DB_ENTRY_CIDR(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_entry_cidr_get_type(), GnomeDbEntryCidr)
 #define GNOME_DB_ENTRY_CIDR_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_entry_cidr_get_type (), GnomeDbEntryCidrClass)
 #define IS_GNOME_DB_ENTRY_CIDR(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_entry_cidr_get_type ())
