@@ -65,7 +65,7 @@ gnome_db_entry_text_get_type (void)
 			(GInstanceInitFunc) gnome_db_entry_text_init
 		};
 		
-		type = g_type_register_static (GNOME_DB_ENTRY_WRAPPER_TYPE, "GnomeDbEntryText", &info, 0);
+		type = g_type_register_static (GNOME_DB_TYPE_ENTRY_WRAPPER, "GnomeDbEntryText", &info, 0);
 	}
 	return type;
 }
@@ -114,7 +114,7 @@ gnome_db_entry_text_new (GnomeDbDataHandler *dh, GdaValueType type)
 	g_return_val_if_fail (type != GDA_VALUE_TYPE_UNKNOWN, NULL);
 	g_return_val_if_fail (gnome_db_data_handler_accepts_gda_type (dh, type), NULL);
 
-	obj = g_object_new (GNOME_DB_ENTRY_TEXT_TYPE, "handler", dh, NULL);
+	obj = g_object_new (GNOME_DB_TYPE_ENTRY_TEXT, "handler", dh, NULL);
 	mgtxt = GNOME_DB_ENTRY_TEXT (obj);
 	gnome_db_data_entry_set_value_type (GNOME_DB_DATA_ENTRY (mgtxt), type);
 
