@@ -27,7 +27,7 @@
 
 G_BEGIN_DECLS
 
-#define GNOME_DB_HANDLER_FILESEL_TYPE          (gnome_db_handler_filesel_get_type())
+#define GNOME_DB_TYPE_HANDLER_FILESEL          (gnome_db_handler_filesel_get_type())
 #define GNOME_DB_HANDLER_FILESEL(obj)          G_TYPE_CHECK_INSTANCE_CAST (obj, gnome_db_handler_filesel_get_type(), GnomeDbHandlerFilesel)
 #define GNOME_DB_HANDLER_FILESEL_CLASS(klass)  G_TYPE_CHECK_CLASS_CAST (klass, gnome_db_handler_filesel_get_type (), GnomeDbHandlerFileselClass)
 #define IS_GNOME_DB_HANDLER_FILESEL(obj)       G_TYPE_CHECK_INSTANCE_TYPE (obj, gnome_db_handler_filesel_get_type ())
