@@ -22,7 +22,6 @@
 #include "gnome-db-data-set.h"
 #include "gnome-db-data-entry.h"
 
-
 /*
  *
  * Data Entry utilities
@@ -74,3 +73,21 @@ GList           *utility_data_set_node_info_compute_values_ext (DataSetNodeInfo
 								GtkTreeIter *iter);
 guint            utility_data_set_node_info_compute_attributes (DataSetNodeInfo *info, GnomeDbDataProxy *proxy, 
 								GtkTreeIter *iter, gboolean *to_be_deleted);
+
+/*
+ *
+ * utilities dealing with storing and retreiving GnomeDbTableField's attributes
+ * which is a list of comma separated keywords
+ *
+ */
+gchar           *utility_table_field_attrs_stringify (guint attributes);
+guint            utility_table_field_attrs_parse     (const gchar *str);
+
+
+/*
+ *
+ * XML Id encoding and decoding
+ *
+ */
+gchar *utility_build_encoded_id (const gchar *prefix, const gchar *id);
+gchar *utility_build_decoded_id (const gchar *prefix, const gchar *id);
